.. veusz documentation master file, created by
   sphinx-quickstart on Sun Feb  5 11:07:00 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Veusz documentation
===================

Jeremy Sanders

Copyright 2017

This document is licensed under the GNU General Public
License, version 2 or greater. Please see the file COPYING for
details, or see `<http://www.gnu.org/licenses/gpl-2.0.html>`_.

This is the documentation for Veusz. Veusz is a multiplatform
scientific plotting package with a graphical user interface.

Contents:

.. toctree::
   :maxdepth: 3

   introduction.rst
   datasets.rst
   api.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

